;*******************************************************************************
;  MSP320F44xx Demo - WDT, Toggle P1.0, Interval Overflow ISR, 32kHz ACLK
;
;   Description: Toggle P1.0 using software timed by WDT ISR. Toggle rate is
;   exactly 250ms based on 32kHz ACLK WDT clock source.  In this example the
;   WDT is configured to divide 32768 watch-crystal(2^15) by 2^13 with an ISR
;   triggered @ 4Hz.
;   ACLK = LFXT1 = 32768Hz, MCLK = SMCLK = DCO
;   //* External watch crystal installed on XIN XOUT is required for ACLK *//	
;
;                MSP430F20xx
;             -----------------
;         /|\|              XIN|-
;          | |                 | 32kHz
;          --|RST          XOUT|-
;            |                 |
;            |             P11.0|-->LED
;
;   M. Buccini / L. Westlund
;   Texas Instruments Inc.
;   September 2005
; 2008/4 Furtos
;   Built with IAR Embedded Workbench Version: 3.40A
;*******************************************************************************
#include  "msp430x44x.h"

extern intwt
;-------------------------------------------------------------------------------
            ORG     0F800h                  ; Program Reset
;-------------------------------------------------------------------------------
//RESET       mov.w   #0280h,SP               ; Initialize stackpointer
Setup       mov.w   #WDT_ADLY_250,&WDTCTL   ; WDT 250ms, ACLK, interval timer
            bis.b   #WDTIE,&IE1             ; Enable WDT interrupt
SetupP1     bis.b   #002h,&P5DIR            ; P1.0 output
            ret                                        ;					
;Mainloop    bis.w   #LPM3+GIE,SR            ; Enter LPM3, interrupts enabled
;            nop                             ; Required only for debugger
                                            ;
;-------------------------------------------------------------------------------
            ORG     0FFF4h                  ; WDT Vector
;WDT_ISR
;call kernel 
;-------------------------------------------------------------------------------
;      xor.b   #002h,&P5OUT            ; Toggle P5.2
;      call  intwt;
 ;           reti                            ;		
                                            ;
;-------------------------------------------------------------------------------
;           Interrupt Vectors
;-------------------------------------------------------------------------------
//            ORG     0FFFEh                  ; MSP430 RESET Vector
//           DW      RESET                   ;
 //           DW      WDT_ISR                 ;
            END
